@@ -14,7 +14,7 @@ function(data = NULL, subset=NULL, formula = NULL,
 stopifnot(is.numeric(correction), 0 <= correction,  
           correction.control %in% c("all", "single", "none"),
           0 <= alphasens, alphasens <= 2, 0 <= alphafpr, alphafpr <= 2,
-          method %in% c("fixed", "ml", "reml"),
+          method %in% c("fixed", "ml", "reml", "mm", "vc"),
           is.numeric(TP) | (is.character(TP) & length(TP) == 1),
           is.numeric(FP) | (is.character(FP) & length(FP) == 1),
           is.numeric(TN) | (is.character(TN) & length(TN) == 1),
@@ -62,19 +62,19 @@ number.of.neg <- FP + TN
 sens<-TP/number.of.pos
 fpr <- FP/number.of.neg
 
-senstrafo <- function(x){return(mada:::talpha(alphasens)$linkfun(x))}
-fprtrafo <- function(x){return(mada:::talpha(alphafpr)$linkfun(x))}
-sensinvtrafo <- function(x){return(mada:::talpha(alphasens)$linkinv(x))}
-fprinvtrafo <- function(x){return(mada:::talpha(alphafpr)$linkinv(x))}
+senstrafo <- function(x){return(talpha(alphasens)$linkfun(x))}
+fprtrafo <- function(x){return(talpha(alphafpr)$linkfun(x))}
+sensinvtrafo <- function(x){return(talpha(alphasens)$linkinv(x))}
+fprinvtrafo <- function(x){return(talpha(alphafpr)$linkinv(x))}
 
 
 trafo.sens <- senstrafo(sens)
 trafo.fpr <- fprtrafo(fpr)
 
 var.trafo.sens <- (sens*(1-sens)/number.of.pos) * 
-  (mada:::jacobiantrafo(alphasens, sens)^2)
+  (jacobiantrafo(alphasens, sens)^2)
 var.trafo.fpr <- (fpr*(1-fpr)/number.of.neg) * 
-  (mada:::jacobiantrafo(alphafpr, fpr)^2)
+  (jacobiantrafo(alphafpr, fpr)^2)
   
 
 # preparations for call to mvmeta.fit
@@ -98,8 +98,8 @@ class(fit) <- "reitsma"
 
 ## modify log likelihood, especially add jacobian
 attr(fit$logLik, "df") <- 2*ncol(mvmeta_X) + 3
-fit$logLik  <-  fit$logLik + sum(log(mada:::jacobiantrafo(alphasens,sens)) + 
-  log(mada:::jacobiantrafo(alphafpr,fpr)))
+fit$logLik  <-  fit$logLik + sum(log(jacobiantrafo(alphasens,sens)) + 
+  log(jacobiantrafo(alphafpr,fpr)))
   
 fit$nobs <- 2*N
 
@@ -159,8 +159,8 @@ function (object, level = 0.95, ...)
   
   if(nrow(tabfixed) == 2){
     tabfixed <- rbind(tabfixed,tabfixed)
-    tabfixed[3,] <- mada:::inv.trafo(object$alphasens, tabfixed[3,])
-    tabfixed[4,] <- mada:::inv.trafo(object$alphafpr, tabfixed[4,])
+    tabfixed[3,] <- inv.trafo(object$alphasens, tabfixed[3,])
+    tabfixed[4,] <- inv.trafo(object$alphafpr, tabfixed[4,])
     tabfixed[3:4,c(2,3,4)] <- NA
     rownames(tabfixed)[3:4] <- c("sensitivity","false pos. rate")
   }
@@ -275,15 +275,15 @@ logLik.reitsma <- function(object, ...){object$logLik}
 
 sroc.reitsma <- function(fit, fpr = 1:99/100, type = "ruttergatsonis", ...){
   stopifnot(type %in% c("ruttergatsonis", "naive"))
-  if(type == "naive"){return(mada:::sroc2(fit, fpr=fpr, ...))}
+  if(type == "naive"){return(sroc2(fit, fpr=fpr, ...))}
   if(type == "ruttergatsonis"){
     sum_fit <- summary(fit)
     Lambda <- summary(fit)$coef_hsroc$Lambda    
     Beta <- summary(fit)$coef_hsroc$beta    
     return(cbind(fpr, 
 #      sens = (1+exp(-Lambda*exp(-0.5*Beta)-exp(-Beta)*log(fpr/(1-fpr))))^(-1)))                 
-      sens = mada:::inv.trafo(fit$alphasens, (Lambda*exp(-Beta/2) + 
-          exp(-Beta)*mada:::trafo(fit$alphafpr, fpr)))))
+      sens = inv.trafo(fit$alphasens, (Lambda*exp(-Beta/2) + 
+          exp(-Beta)*trafo(fit$alphafpr, fpr)))))
   }
 }
 
@@ -292,7 +292,7 @@ mcsroc.reitsma <- function(fit, fpr = 1:99/100, replications = 10000, lambda = 1
 }
   
 ROCellipse.reitsma <- function(x, level = 0.95, add = FALSE, pch = 1, ...){
-  mada:::ROC.ellipse2(x, nobs = x$nobs/2, conf.level = level, add = add, pch = pch, ...)
+  ROC.ellipse2(x, conf.level = level, add = add, pch = pch, ...)
 }
 
 crosshair.reitsma <- function(x, level = 0.95, length = 0.1, pch = 1, ...){
@@ -343,8 +343,8 @@ plot.reitsma <- function(x, extrapolate = FALSE, plotsumm = TRUE, level = 0.95,
     Sigma <- x$Psi + vcov(x)
     talphaellipse <- ellipse(Sigma, centre = mu, level = level)
     predellipse <- matrix(0, ncol = 2, nrow = nrow(talphaellipse))
-    predellipse[,1] <- mada:::inv.trafo(alpha.fpr, talphaellipse[,2])
-    predellipse[,2] <- mada:::inv.trafo(alpha.sens, talphaellipse[,1])
+    predellipse[,1] <- inv.trafo(alpha.fpr, talphaellipse[,2])
+    predellipse[,2] <- inv.trafo(alpha.sens, talphaellipse[,1])
     lines(predellipse, lty = predlty, lwd = predlwd)
 }
   
@@ -358,7 +358,8 @@ confint.reitsma <- function (object, parm, level = 0.95, ...)
 
   a <- (1 - level)/2
   a <- c(a, 1 - a)
-  pct <- stats:::format.perc(a, 3)
+  pct <- paste(format(100 * a, trim = TRUE, scientific = FALSE, digits = 3),
+               "%")
   fac <- qnorm(a)
   ci <- array(NA, dim = c(length(parm), 2L), dimnames = list(parm, 
                                                              pct))
@@ -377,13 +378,13 @@ AUC.reitsma <- function(x, fpr = 1:99/100, ...){
   mu2 <- estimate[2]
   sigma2 <- x$Psi[2,2]
   sigma <- x$Psi[1,2]  
-  rsroc <- function(x){mada:::calc.sroc(x, alpha.sens, alpha.fpr, mu1, mu2, sigma2, sigma)}
-  AUC <- mada:::AUC.default(rsroc, fpr = fpr, ...)
+  rsroc <- function(x){calc.sroc(x, alpha.sens, alpha.fpr, mu1, mu2, sigma2, sigma)}
+  AUC <- AUC.default(rsroc, fpr = fpr, ...)
   obsfprrange <- range(fpr(x$freqdata))
   obsfprrange[1] <- max(0.01,obsfprrange[1])
   obsfprrange[2] <- min(0.99,obsfprrange[2])
   obsfpr <- seq(from = obsfprrange[1], to = obsfprrange[2], length.out = 99)
-  pAUC <- mada:::AUC.default(rsroc, fpr = obsfpr, ...)
+  pAUC <- AUC.default(rsroc, fpr = obsfpr, ...)
   names(pAUC) <- c("pAUC")
   return(c(AUC,pAUC))
 }
